#
# spec file for package ghc-smallcaps
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name smallcaps
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.0.4
Release:        8.1
Summary:        Flatten camel case text in LaTeX files
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel

%description
Smallcaps is a pre-processor library for LaTeX files. The library comes with an
executable that makes most functionality accessible through a command line
interface. The pre-processor formats sequences of uppercase letters with TeX's
'\small' macro or whatever you configure. Uppercase letters at the beginning of
sentences are not formatted. Other formatting conditions can be configured by
the user.

The executable can be configured through its command line arguments as well as
through TeX comments. In the default configuration, lesscase does not change
the content of any macro argument or environment (different from document).
More and less restrictive configuration profiles can be activated and adapted.
Configurations can be stored and restored at any time, even while processing
the input file.

["Text.SmallCaps"] exports the main program as library.

["Text.SmallCaps.Config"] specifies the default configuration values for
"Text.SmallCaps".

["Text.SmallCaps.TeXParser"] parses 'Text' to a 'TeXElement' token stream.

["Text.SmallCaps.TeXLaTeXParser"] parses a 'TeXElement' token stream and
produces a 'LaTeXElement' token stream.

["Text.SmallCaps.DocumentParser"] replaces uppercase letters in 'LaTeXElement'
token streams.

A simple program can be defined as

' import Data.Default ( def ) import Text.SmallCaps ( smallcaps ) import
Text.SmallCaps.Config ( defaultProfile ) main = smallcaps def defaultProfile '

This is virtually all the code that is necessary to implement the executable
'lesscase'. Have a look in the source of the executable 'twocase' which only
formats sequences of two or more uppercase letters. It is a good reference for
understanding the API changes that took place between the revisions 0.5 and
0.6.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%{_bindir}/lesscase
%{_bindir}/twocase

%files devel -f %{name}-devel.files
%doc doc

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Jan 18 2017 psimons@suse.com
- Update to version 0.6.0.4 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.0.3 revision 0 with cabal2obs.
